
####  a quick tour of websites relevant to the matR project.

browseURL("http://cran.r-project.org")
browseURL("http://cran.r-project.org/web/views/")
browseURL("http://bioconductor.org/")
browseURL("http://mg-rast.org")
browseURL("http://github.org/MG-RAST/")
browseURL("http://api.mg-rast.org/")
browseURL("http://github.org/MG-RAST/matR")
